==> openhpi_2.12.0.orig.tar.gz: openhpi-2.12.0/plugins/oa_soap/oa_soap_power.h <==
/*
 * Copyright (C) 2007-2008, Hewlett-Packard Development Company, LLP
 *                     All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the distribution.
 *
 * Neither the name of the Hewlett-Packard Corporation, nor the names
 * of its contributors may be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Author(s)
 *      Raghavendra P.G. <raghavendra.pg@hp.com>
 */

#ifndef _OA_SOAP_POWER_H
#define _OA_SOAP_POWER_H

/* Include files */
#include "oa_soap_utils.h"

#define HALF_SECOND 500000
#define TIMEOUT 60
#define SERVER_POWER_OFF_WAIT_PERIOD 5

SaErrorT get_server_power_state(SOAP_CON *con,
                                SaHpiInt32T bay_number,
                                SaHpiPowerStateT *state);

SaErrorT get_interconnect_power_state(SOAP_CON *con,
                                      SaHpiInt32T bay_number,
                                      SaHpiPowerStateT *state);

SaErrorT set_server_power_state(SOAP_CON *con,
                                SaHpiInt32T bay_number,
                                SaHpiPowerStateT state);

SaErrorT set_interconnect_power_state(SOAP_CON *con,
                                      SaHpiInt32T bay_number,
                                      SaHpiPowerStateT state);

SaErrorT oa_soap_get_power_state(void *oh_handler,
                                 SaHpiResourceIdT resource_id,
                                 SaHpiPowerStateT *state);

SaErrorT oa_soap_set_power_state(void *oh_handler,
                                 SaHpiResourceIdT resource_id,
                                 SaHpiPowerStateT state);

#endif

==> openhpi_2.14.0.orig.tar.gz: openhpi-2.14.0/plugins/oa_soap/oa_soap_power.h <==
/*
 * Copyright (C) 2007-2008, Hewlett-Packard Development Company, LLP
 *                     All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the distribution.
 *
 * Neither the name of the Hewlett-Packard Corporation, nor the names
 * of its contributors may be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Author(s)
 *      Raghavendra P.G. <raghavendra.pg@hp.com>
 */

#ifndef _OA_SOAP_POWER_H
#define _OA_SOAP_POWER_H

/* Include files */
#include "oa_soap_utils.h"

/* Seconds to sleep between polls when checking for powerdown */
#define OA_POWEROFF_POLL_INTERVAL	2

/* Max number of times to poll when checking for powerdown */
#define OA_MAX_POWEROFF_POLLS		100

SaErrorT get_server_power_state(SOAP_CON *con,
                                SaHpiInt32T bay_number,
                                SaHpiPowerStateT *state);

SaErrorT get_interconnect_power_state(SOAP_CON *con,
                                      SaHpiInt32T bay_number,
                                      SaHpiPowerStateT *state);

SaErrorT set_server_power_state(SOAP_CON *con,
                                SaHpiInt32T bay_number,
                                SaHpiPowerStateT state);

SaErrorT set_interconnect_power_state(SOAP_CON *con,
                                      SaHpiInt32T bay_number,
                                      SaHpiPowerStateT state);

SaErrorT oa_soap_get_power_state(void *oh_handler,
                                 SaHpiResourceIdT resource_id,
                                 SaHpiPowerStateT *state);

SaErrorT oa_soap_set_power_state(void *oh_handler,
                                 SaHpiResourceIdT resource_id,
                                 SaHpiPowerStateT state);

#endif
